===============================
🍌🥧: Banano Python Library
===============================

.. image:: https://img.shields.io/pypi/l/bananopy.svg
    :target: https://github.com/milkyklim/bananopy/blob/master/LICENSE
    :alt: License

.. image:: https://github.com/milkyklim/bananopy/workflows/CI/badge.svg
    :target: https://github.com/milkyklim/bananopy/actions
    :alt: Build Status

.. image:: https://readthedocs.org/projects/bananopy/badge/?version=latest
    :target: http://bananopy.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/bananopy.svg
    :target: https://pypi.python.org/pypi/
    :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/v/bananopy.svg
    :target: https://pypi.python.org/pypi/bananopy
    :alt: Package Version

.. image:: https://img.shields.io/badge/Banano%20Node-v20.0-yellow
    :alt: Banano Node Version

🍌🥧 is a python wrapper for Banano node communication.
It takes care of RPC responses (type conversions) and exposes a pythonic API for making RPC calls.

Full list of RPC calls is coming from `docs <https://docs.nano.org/commands/rpc-protocol/>`_.
